summaryrefslogtreecommitdiffstats
path: root/tests/test_encode1.c
diff options
context:
space:
mode:
Diffstat (limited to 'tests/test_encode1.c')
-rw-r--r--tests/test_encode1.c27
1 files changed, 14 insertions, 13 deletions
diff --git a/tests/test_encode1.c b/tests/test_encode1.c
index f46e60a6..c5131e47 100644
--- a/tests/test_encode1.c
+++ b/tests/test_encode1.c
@@ -1,31 +1,32 @@
/* A very simple encoding test case using person.proto.
* Just puts constant data in the fields and writes the
* data to stdout.
*/
#include <stdio.h>
#include <pb_encode.h>
#include "person.pb.h"
-/* This binds the pb_ostream_t into the stdout stream */
-bool streamcallback(pb_ostream_t *stream, const uint8_t *buf, size_t count)
-{
- FILE *file = (FILE*) stream->state;
- return fwrite(buf, 1, count, file) == count;
-}
-
int main()
{
/* Initialize the structure with constants */
Person person = {"Test Person 99", 99, true, "test@person.com",
- 1, {{"555-12345678", true, Person_PhoneType_MOBILE}}};
-
- /* Prepare the stream, output goes directly to stdout */
- pb_ostream_t stream = {&streamcallback, stdout, SIZE_MAX, 0};
+ 3, {{"555-12345678", true, Person_PhoneType_MOBILE},
+ {"99-2342", false, 0},
+ {"1234-5678", true, Person_PhoneType_WORK},
+ }};
+
+ uint8_t buffer[512];
+ pb_ostream_t stream = pb_ostream_from_buffer(buffer, sizeof(buffer));
/* Now encode it and check if we succeeded. */
if (pb_encode(&stream, Person_fields, &person))
+ {
+ fwrite(buffer, stream.bytes_written, 1, stdout);
return 0; /* Success */
+ }
else
+ {
return 1; /* Failure */
+ }
}
@@ -1,31 +1,32 @@
/* A very simple encoding test case using person.proto.
- * Just puts constant data in the fields and writes the
- * data to stdout.
+ * Just puts constant data in the fields and encodes into
+ * buffer, which is then written to stdout.
*/
#include <stdio.h>